@@ -74,9 +74,8 @@ enum {
 
 enum {
     PROP_0,
-    PROP_KEY_TYPE,
-    PROP_KEY_DESC,
-    PROP_LOCATION
+    PROP_SOURCE_TAG,
+    PROP_SOURCE_LOCATION
 };
 
 static gpgme_error_t
@@ -89,10 +88,13 @@ passphrase_get (gconstpointer dummy, const gchar *passphrase_hint,
     gchar *label = NULL;
     gchar *errmsg = NULL;
     const gchar *pass;
-    
-    if (passphrase_info && strlen(passphrase_info) < 16)
+    gboolean confirm = FALSE;
+
+    if (passphrase_info && strlen(passphrase_info) < 16) {
         flags |= SEAHORSE_PASS_NEW;
-    
+        confirm = TRUE;
+    }
+
     if (passphrase_hint)
         split_uid = g_strsplit (passphrase_hint, " ", 2);
 
@@ -114,7 +116,7 @@ passphrase_get (gconstpointer dummy, const gchar *passphrase_hint,
     g_strfreev (split_uid);
 
     dialog = seahorse_passphrase_prompt_show (NULL, errmsg ? errmsg : label, 
-                                              NULL, NULL, FALSE);
+                                              NULL, NULL, confirm);
     g_free (label);
     g_free (errmsg);
     
@@ -303,13 +305,12 @@ seahorse_gpgme_source_class_init (SeahorseGpgmeSourceClass *klass)
     gobject_class->set_property = seahorse_gpgme_source_set_property;
     gobject_class->get_property = seahorse_gpgme_source_get_property;
  
-	g_object_class_override_property (gobject_class, PROP_KEY_TYPE, "key-type");
-	g_object_class_override_property (gobject_class, PROP_KEY_DESC, "key-desc");
-	g_object_class_override_property (gobject_class, PROP_LOCATION, "location");
+	g_object_class_override_property (gobject_class, PROP_SOURCE_TAG, "source-tag");
+	g_object_class_override_property (gobject_class, PROP_SOURCE_LOCATION, "source-location");
 	
 	seahorse_registry_register_type (NULL, SEAHORSE_TYPE_GPGME_SOURCE, "source", "local", SEAHORSE_PGP_STR, NULL);
 
-	seahorse_registry_register_function (NULL, seahorse_pgp_key_calc_cannonical_id, "canonize", SEAHORSE_PGP_STR, NULL);
+	seahorse_registry_register_function (NULL, seahorse_pgp_key_canonize_id, "canonize", SEAHORSE_PGP_STR, NULL);
 }
 
 static void 
@@ -431,13 +432,10 @@ seahorse_gpgme_source_get_property (GObject *object, guint prop_id, GValue *valu
                                   GParamSpec *pspec)
 {
     switch (prop_id) {
-    case PROP_KEY_TYPE:
+    case PROP_SOURCE_TAG:
         g_value_set_uint (value, SEAHORSE_PGP);
         break;
-    case PROP_KEY_DESC:
-        g_value_set_string (value, _("PGP Key"));
-        break;
-    case PROP_LOCATION:
+    case PROP_SOURCE_LOCATION:
         g_value_set_enum (value, SEAHORSE_LOCATION_LOCAL);
         break;
     }
@@ -474,7 +472,7 @@ add_key_to_context (SeahorseGpgmeSource *psrc, gpgme_key_t key)
 	g_return_val_if_fail (key->subkeys && key->subkeys->keyid, NULL);
     
 	id = key->subkeys->keyid;
-	keyid = seahorse_pgp_key_calc_cannonical_id (id);
+	keyid = seahorse_pgp_key_canonize_id (id);
 	g_return_val_if_fail (keyid, NULL);
     
 	g_assert (SEAHORSE_IS_GPGME_SOURCE (psrc));
@@ -688,7 +686,7 @@ keyload_handler (SeahorseLoadOperation *lop)
         }
         
         g_return_val_if_fail (key->subkeys && key->subkeys->keyid, FALSE);
-        keyid = seahorse_pgp_key_calc_cannonical_id (key->subkeys->keyid);
+        keyid = seahorse_pgp_key_canonize_id (key->subkeys->keyid);
         
         /* Invalid id from GPG ? */
         if (!keyid) {
@@ -846,7 +844,7 @@ prepare_import_results (SeahorseGpgmeOperation *pop, SeahorseGpgmeSource *psrc)
             if (!GPG_IS_OK (import->result))
                 continue;
             
-            keyid = seahorse_pgp_key_calc_cannonical_id (import->fpr);
+            keyid = seahorse_pgp_key_canonize_id (import->fpr);
             if (!keyid) {
                 g_warning ("imported non key with strange keyid: %s", import->fpr);
                 continue;
